@@ -29,7 +29,7 @@
 #include "qtgui/dockrxopt.h"
 
 #define DEFAULT_RC_PORT            7356
-#define DEFAULT_RC_ALLOWED_HOSTS   "::ffff:127.0.0.1"
+#define DEFAULT_RC_ALLOWED_HOSTS   "127.0.0.1"
 
 RemoteControl::RemoteControl(QObject *parent) :
     QObject(parent)
@@ -167,19 +167,22 @@ void RemoteControl::acceptConnection()
     rc_socket = rc_server.nextPendingConnection();
 
     // check if host is allowed
-    QString address = rc_socket->peerAddress().toString();
-    if (rc_allowed_hosts.indexOf(address) == -1)
+    auto address = rc_socket->peerAddress();
+
+    for (auto allowed_host : rc_allowed_hosts)
     {
-        std::cout << "*** Remote connection attempt from " << address.toStdString()
-                  << " (not in allowed list)" << std::endl;
-        rc_socket->close();
-        rc_socket->deleteLater();
-        rc_socket = 0;
-    }
-    else
-    {
-        connect(rc_socket, SIGNAL(readyRead()), this, SLOT(startRead()));
+        if (address.isEqual(QHostAddress(allowed_host)))
+        {
+            connect(rc_socket, SIGNAL(readyRead()), this, SLOT(startRead()));
+            return;
+        }
     }
+
+    std::cout << "*** Remote connection attempt from " << address.toString().toStdString()
+              << " (not in allowed list)" << std::endl;
+    rc_socket->close();
+    rc_socket->deleteLater();
+    rc_socket = 0;
 }
 
 /*! \brief Start reading from the socket.
@@ -197,7 +200,11 @@ void RemoteControl::startRead()
     if (bytes_read < 2)  // command + '\n'
         return;
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     QStringList cmdlist = QString(buffer).trimmed().split(" ", QString::SkipEmptyParts);
+#else
+    QStringList cmdlist = QString(buffer).trimmed().split(" ", Qt::SkipEmptyParts);
+#endif
 
     if (cmdlist.size() == 0)
         return;
@@ -623,13 +630,13 @@ QString RemoteControl::cmd_get_level(QStringList cmdlist)
     {
         answer = QString("%1\n").arg(squelch_level, 0, 'f', 1);
     }
-    else if (lvl.contains(QRegExp("_GAIN$")))
+    else if (lvl.endsWith("_GAIN"))
     {
-        QString name = lvl.remove(QRegExp("_GAIN$"));
+        lvl.chop(5);
         answer = QString("RPRT 1\n");
         for(auto &g : gains)
         {
-            if(name == QString::fromStdString(g.name))
+            if(lvl == QString::fromStdString(g.name))
             {
                 answer = QString("%1\n").arg(g.value);
                 break;
@@ -672,13 +679,13 @@ QString RemoteControl::cmd_set_level(QStringList cmdlist)
             answer = QString("RPRT 1\n");
         }
     }
-    else if (lvl.contains(QRegExp("_GAIN$")))
+    else if (lvl.endsWith("_GAIN"))
     {
-        QString name = lvl.remove(QRegExp("_GAIN$"));
+        lvl.chop(5);
 
         bool ok;
         double gain = cmdlist.value(2, "ERR").toDouble(&ok);
-        if (ok && setGain(name, gain))
+        if (ok && setGain(lvl, gain))
             answer = QString("RPRT 0\n");
         else
             answer = QString("RPRT 1\n");
