@@ -31,7 +31,8 @@
 
 Afsk1200Win::Afsk1200Win(QWidget *parent) :
     QMainWindow(parent),
-    ui(new Ui::Afsk1200Win)
+    ui(new Ui::Afsk1200Win),
+    tmpbuf(CORRLEN, 0.0)
 {
     ui->setupUi(this);
 
@@ -61,21 +62,14 @@ Afsk1200Win::~Afsk1200Win()
 /*! \brief Process new set of samples. */
 void Afsk1200Win::process_samples(float *buffer, int length)
 {
-    int overlap = 18;
-    int i;
-
-    for (i = 0; i < length; i++) {
-        tmpbuf.append(buffer[i]);
+    for (int i = 0; i < length; i++) {
+        tmpbuf.push_back(buffer[i]);
     }
 
     decoder->demod(tmpbuf.data(), length);
 
     /* clear tmpbuf and store "overlap" */
-    tmpbuf.clear();
-    for (i = length-overlap; i < length; i++) {
-        tmpbuf.append(buffer[i]);
-    }
-
+    tmpbuf.erase(tmpbuf.begin(), tmpbuf.begin() + length);
 }
 
 
